Cookie

Struct Cookie 

pub struct Cookie {
    pub cookie_value: Vec<u8>,
}
Components::Cookie-valuetype — Spec 6.5.2.4 (S. 21).

Spec-IDL:

module Components {
    valuetype Cookie {
        private CORBA::OctetSeq cookieValue;
    };
};

Cookies werden von Multiplex-Receptacles erzeugt und identifizieren eine konkrete Connection auf dem Receptacle (Spec 6.5.2.4).

Fields

cookie_value: Vec<u8>

private CORBA::OctetSeq cookieValue; — opaque Bytes, Receptacle-implementation-defined.

Implementations

pub fn new(cookie_value: Vec<u8>) -> Self

Konstruktor — Spec 6.5.2.4 (S. 21).

pub fn truncate_to_base(&self) -> Self

Spec 6.5.2.4 (S. 22): “any derived cookie types shall be truncatable to Cookie, and the information preserved in the cookieValue octet sequence shall be sufficient for the receptacle implementation to identify the cookie and its associated connected reference.”