transform_component

Function transform_component 

pub fn transform_component(comp: &ComponentDef) -> ComponentEquivalent
Spec 6.3.2 (p. 12) + 6.4.1 / 6.5.1 / 6.6.x — generates the component equivalent interface including all port operations.

Inheritance (6.3.2):

  • Without supports and without base: : Components::CCMObject.
  • With base: : <base> (CCMObject is transitive).
  • With supports: additionally the supported interfaces.

Body (6.4.1 / 6.5.1 / 6.6.x): all port decls are translated into operations on the equivalent interface.