pub struct Cookie {
pub cookie_value: Vec<u8>,
}Expand description
Components::Cookie-valuetype — Spec 6.5.2.4 (S. 21).
Spec-IDL:
module Components {
valuetype Cookie {
private CORBA::OctetSeq cookieValue;
};
};Cookies werden von Multiplex-Receptacles erzeugt und identifizieren eine konkrete Connection auf dem Receptacle (Spec 6.5.2.4).
Fields
private CORBA::OctetSeq cookieValue; — opaque Bytes,
Receptacle-implementation-defined.
Implementations
Sourceimpl Cookie
impl Cookie
Sourcepub fn truncate_to_base(&self) -> Self
pub fn truncate_to_base(&self) -> Self
Spec 6.5.2.4 (S. 22): “any derived cookie types shall be truncatable to Cookie, and the information preserved in the cookieValue octet sequence shall be sufficient for the receptacle implementation to identify the cookie and its associated connected reference.”